@@ -1,11 +1,55 @@
 # encoding: utf-8
 import os
+import platform
 import re
+import sys
 from argparse import ArgumentParser
 
+import PIL  # it exists, was checked on main
+import piexif
+
+from optimize_images import __version__
 from optimize_images.constants import DEFAULT_QUALITY, SUPPORTED_FORMATS
 
 
+def get_version_info() -> str:
+    """ Get a string that displays current application version as well as
+        some useful environment info.
+    """
+    piexif_version = piexif.VERSION
+
+    try:
+        import watchdog.version
+        wd_version = watchdog.version.VERSION_STRING
+    except ImportError:
+        wd_version = "missing (package needed for watching folders for changes)"
+        
+    try:
+        pillow_version = PIL.__version__
+    except AttributeError:
+        pillow_version = PIL.PILLOW_VERSION
+
+    python_version = f'Python {platform.python_version()} ({sys.executable})'
+
+    return f'\nOptimize Images {__version__}' \
+           f'\n\nRunning environment:' \
+           f'\n  - Location: {sys.argv[0]}' \
+           f'\n  - Pillow {pillow_version}' \
+           f'\n  - Piexif {piexif_version}' \
+           f'\n  - {python_version}' \
+           f'\n\nOptional packages:' \
+           f'\n  - Watchdog {wd_version}\n\n'
+
+
+def get_formats() -> str:
+    """ Get a string that displays a list of supported formats. """
+    formats = ', '.join(SUPPORTED_FORMATS).strip().upper()
+    msg = "These are the image formats currently supported (please " \
+          "note that any files without one of these file extensions " \
+          "will be ignored):"
+    return f"\n{msg} {formats}\n\n"
+
+
 def get_args():
     desc = 'A command-line utility written in pure Python to reduce the file ' \
            'size of images. You must explicitly pass it a path to the image ' \
@@ -25,8 +69,8 @@ def get_args():
                 'any images found in all of its subdirectories.'
     parser.add_argument('path', nargs="?", type=str, help=path_help)
 
-    parser.add_argument('-v', '--version', action='version',
-                        version=__import__('optimize_images').__version__)
+    parser.add_argument('-v', '--version', action='store_true',
+                        help="Check the version of this app and its environment.")
 
     sf_help = 'Display the list of image formats currently supported.'
     parser.add_argument('-s', '--supported', dest="supported_formats",
@@ -156,13 +200,11 @@ def get_args():
     quality = args.quality
     watch_dir = args.watch_directory
 
+    if args.version:
+        parser.exit(status=0, message=get_version_info())
+
     if args.supported_formats:
-        formats = ', '.join(SUPPORTED_FORMATS).strip().upper()
-        msg = "These are the image formats currently supported (please " \
-              "note that any files without one of these file extensions " \
-              "will be ignored):"
-        msg = f"\n{msg} {formats}\n\n"
-        parser.exit(status=0, message=msg)
+        parser.exit(status=0, message=get_formats())
 
     if args.path:
         src_path = os.path.expanduser(args.path)
@@ -206,8 +248,8 @@ def get_args():
               "bright red you can use: '-bg 255 0 0' or '-hbg #FF0000'.\n\n"
         parser.exit(status=0, message=msg)
 
-    return watch_dir, src_path, recursive, quality, args.remove_transparency, \
+    return src_path, watch_dir, recursive, quality, args.remove_transparency, \
            args.reduce_colors, args.max_colors, args.max_width, args.max_height, \
            args.keep_exif, args.convert_all, args.convert_big, args.force_delete, \
            bg_color, args.grayscale, args.no_comparison, args.fast_mode, \
-           args.jobs
+           args.jobs
\ No newline at end of file
