@@ -4,19 +4,16 @@ https://engineeringblog.yelp.com/2017/06/making-photos-smaller.html
 """
 from functools import lru_cache
 from io import BytesIO
+from typing import Optional, Tuple
+
+from PIL import Image
+from PIL import ImageChops, ImageStat
 from math import log
 
-from optimize_images.constants import DEFAULT_QUALITY
-
-try:
-    from PIL import Image
-    from PIL import ImageChops, ImageStat
-except ImportError:
-    msg = 'This application requires Pillow to be installed. Please, install it first.'
-    raise ImportError(msg)
+from .constants import DEFAULT_QUALITY
 
 
-def compare_images(img1, img2):
+def compare_images(img1: Image.Image, img2: Image.Image) -> Optional[float]:
     """Calculate the difference between two images of the same size
     by comparing channel values at the pixel level.
     `delete_diff_file`: removes the diff image after ratio found
@@ -41,7 +38,7 @@ def compare_images(img1, img2):
     return diff_ratio * 100
 
 
-def get_diff_at_quality(photo, quality):
+def get_diff_at_quality(photo, quality: int) -> float:
     """Return a difference score for this JPEG image saved at the specified quality
 
     A SSIM score would be much better, but currently there is no pure Python
@@ -63,15 +60,16 @@ def get_diff_at_quality(photo, quality):
 
 
 @lru_cache(maxsize=None)
-def _diff_iteration_count(lo, hi):
+def _diff_iteration_count(low: int, high: int) -> int:
     """Return the depth of the binary search tree for this range"""
-    if lo >= hi:
+    if low >= high:
         return 0
     else:
-        return int(log(hi - lo, 2)) + 1
+        return int(log(high - low, 2)) + 1
 
 
-def jpeg_dynamic_quality(original_photo, use_dynamic_quality=True):
+def jpeg_dynamic_quality(original_photo: Image.Image,
+                         use_dynamic_quality: bool = True) -> Tuple[int, float]:
     """Return an integer representing the quality that this JPEG image should be
     saved at to attain the quality threshold specified for this photo class.
 
@@ -79,16 +77,16 @@ def jpeg_dynamic_quality(original_photo, use_dynamic_quality=True):
         original_photo - a prepared PIL JPEG image (only JPEG is supported)
     """
     diff_goal = 0.992
-    hi = DEFAULT_QUALITY
-    lo = hi - 5
+    high = DEFAULT_QUALITY
+    low = high - 5
 
     # working on a smaller size image doesn't give worse results but is faster
     # changing this value requires updating the calculated thresholds
     photo = original_photo.resize((400, 400))
 
     if not use_dynamic_quality:
-        default_diff = get_diff_at_quality(photo, hi)
-        return hi, default_diff
+        default_diff = get_diff_at_quality(photo, high)
+        return high, default_diff
 
     # 95 is the highest useful value for JPEG. Higher values cause different behavior
     # Used to establish the image's intrinsic ssim without encoder artifacts
@@ -97,8 +95,8 @@ def jpeg_dynamic_quality(original_photo, use_dynamic_quality=True):
     selected_quality = selected_diff = None
 
     # loop bisection. ssim/diff function increases monotonically so this will converge
-    for i in range(_diff_iteration_count(lo, hi)):
-        curr_quality = (lo + hi) // 2
+    for _ in range(_diff_iteration_count(low, high)):
+        curr_quality = (low + high) // 2
         curr_diff = get_diff_at_quality(photo, curr_quality)
         diff_ratio = curr_diff / normalized_diff
 
@@ -106,12 +104,12 @@ def jpeg_dynamic_quality(original_photo, use_dynamic_quality=True):
             # continue to check whether a lower quality level also exceeds the goal
             selected_quality = curr_quality
             selected_diff = curr_diff
-            hi = curr_quality
+            high = curr_quality
         else:
-            lo = curr_quality
+            low = curr_quality
 
     if selected_quality:
         return selected_quality, selected_diff
     else:
-        default_diff = get_diff_at_quality(photo, hi)
-        return hi, default_diff
+        default_diff = get_diff_at_quality(photo, high)
+        return high, default_diff
